==> cpyth-1.2.7.tgz: cpyth-1.2.7/interface/main.f <==
*************************************************************************
*                       M A I N   program                               *
*          for CompHEP 4.10  -  PYTHIA 6.2 interface                    *
* uses unweighted events from CompHEP output as PYTHIA external process *
*************************************************************************
*  25.11.2001         Ilyin V.A.                                        *
*************************************************************************
      IMPLICIT DOUBLE PRECISION(A-H, O-Z)
*...PYTHIA common blocks
      COMMON/PYPARS/MSTP(200),PARP(200),MSTI(200),PARI(200)
      COMMON /PYSUBS/MSEL,MSELPD,MSUB(500),KFIN(2,-40:40),CKIN(200)
      COMMON/PYDAT1/MSTU(200),PARU(200),MSTJ(200),PARJ(200)
      COMMON/PYDAT2/KCHG(500,4),PMAS(500,4),PARF(2000),VCKM(4,4)
      COMMON/PYDAT3/MDCY(500,3),MDME(8000,2),BRAT(8000),KFDP(8000,5)
      COMMON/PYINT4/MWID(500),WIDS(500,5)
      COMMON/PYJETS/N,NPAD,K(4000,5),P(4000,5),V(4000,5)
      SAVE

      INTEGER MAXPUP
      PARAMETER (MAXPUP=100)
      INTEGER IDBMUP,PDFGUP,PDFSUP,IDWTUP,NPRUP,LPRUP
      DOUBLE PRECISION EBMUP,XSECUP,XERRUP,XMAXUP
      COMMON/HEPRUP/IDBMUP(2),EBMUP(2),PDFGUP(2),PDFSUP(2),
     &IDWTUP,NPRUP,XSECUP(MAXPUP),XERRUP(MAXPUP),XMAXUP(MAXPUP),
     &LPRUP(MAXPUP)
      SAVE /HEPRUP/

      INTEGER MAXNUP
      PARAMETER (MAXNUP=500)
      INTEGER NUP,IDPRUP,IDUP,ISTUP,MOTHUP,ICOLUP
      DOUBLE PRECISION XWGTUP,SCALUP,AQEDUP,AQCDUP,PUP,VTIMUP,SPINUP
      COMMON/HEPEUP/NUP,IDPRUP,XWGTUP,SCALUP,AQEDUP,AQCDUP,IDUP(MAXNUP),
     &ISTUP(MAXNUP),MOTHUP(2,MAXNUP),ICOLUP(2,MAXNUP),PUP(5,MAXNUP),
     &VTIMUP(MAXNUP),SPINUP(MAXNUP)
      SAVE /HEPEUP/
      
*...CompHEP-PYTHIA interface
      INTEGER KFB,IS,NEVPY,FIREVT,ISMEAR
      CHARACTER PROCESS*80,EVFILE*500,BEAM*16
      DOUBLE PRECISION SQRTS,RPDTY,BMASS
      COMMON/BEAMS/SQRTS,RPDTY,KFB(2),BMASS(2),BEAM(2)
      COMMON/ISMEAR/ISMEAR
      COMMON/INPARM/IS,NEVPY,FIREVT,PROCESS,EVFILE
      SAVE

****************** read CompHEP output header and input parameters
*...read input parameters from the file (INPARM.DAT)
      CALL RINPAR
*...switch to smear the mass of unstable particles in CompHEP out-state
      ISMEAR=1     ! 0 - no Breit-Wigner smearing, 1- yes
*...set some phys. parameters (masses etc) in PYTHIA according to CompHEP
*...default values
      CALL PHPARS
*...read the number of subprocesses
      CALL SUBNUM
*...read header for event flow
      CALL RHEADER
*...If firevt doesn't equal 1, processing begins from firevt event
       call SHIFT(FIREVT)

*************   USER can change these switches or add others ********

*...Independent(MSTJ(1)=2)/LUND(=1)/NO(=0) Fragmentation Model switch
      MSTJ(1) = 1
*...switch on/off fragmentation and decays
      MSTP(111) = 1
*...switch on/off initial QCD and QED state radiation
      MSTP(61) = 1
*...switch on/off final state showers
      MSTP(71) = 1
*...switch off multiple interactions
      MSTP(81) = 1
*...title page off
      MSTU(12) = 0
*...no initialization and diff.cross-section maximization print-out
      MSTP(122) = 0

********************************************************************
*...initialize PYTHIA (using CompHEP output for kin.frame)
      CALL PYINIT('USER',' ',' ',0d0)
      CALL PHPARS    ! set again phys.parameters according to
                     ! CompHEP default values
*********************************************************
*...generate events by PYTHIA
      nnev = 0      
c      CALL HEPRUP_PRINT   ! Print HEPRUP Common block
      DO 200 IEV=1,NEVPY
        CALL PYEVNT

*...<<<<<<< USER's routines for analysis should be call here >>>>>> 
c      CALL HEPEUP_PRINT   ! Print other parameters from HEPEUP Common block
        call pylist(7)    ! This is an example of user's routine:
        call pylist(1)    ! This is an example of user's routine:
c        call PYHEPC(1)      ! Convert PYJETS event to HEPEVT format.
*...<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

*...check end of file with partonic events
        IF (NUP.eq.0) THEN
            goto 300
        ELSE
            nnev = iev
        ENDIF

200   CONTINUE               ! DO 200 IEV=1,NEVPY

300   CONTINUE
*...cross section table
      CALL PYSTAT(1)

      write(*,*) '  Generated events = ',nnev

      END

==> cpyth-2.0.1.tgz: cpyth-2.0.1/interface/main.f <==
*************************************************************************
*                       M A I N   program                               *
*          for CompHEP 4.10  -  PYTHIA 6.2 interface                    *
* uses unweighted events from CompHEP output as PYTHIA external process *
*************************************************************************
*  25.11.2001         Ilyin V.A.                                        *
*************************************************************************
      IMPLICIT REAL*8(A-H, O-Z)
      IMPLICIT INTEGER(I-N)
*...PYTHIA common blocks
      COMMON/PYPARS/MSTP(200),PARP(200),MSTI(200),PARI(200)
      COMMON /PYSUBS/MSEL,MSELPD,MSUB(500),KFIN(2,-40:40),CKIN(200)
      COMMON/PYDAT1/MSTU(200),PARU(200),MSTJ(200),PARJ(200)
      COMMON/PYDAT2/KCHG(500,4),PMAS(500,4),PARF(2000),VCKM(4,4)
      COMMON/PYDAT3/MDCY(500,3),MDME(8000,2),BRAT(8000),KFDP(8000,5)
      COMMON/PYINT4/MWID(500),WIDS(500,5)
      COMMON/PYJETS/N,NPAD,K(4000,5),P(4000,5),V(4000,5)

*...PYTHIA USER PROCESS INFO COMMON BLOCK
      INTEGER MAXPUP   ! Maximum number of processes to be interfaced at one time
      PARAMETER (MAXPUP=100)
      INTEGER IDBMUP,PDFGUP,PDFSUP,IDWTUP,NPRUP,LPRUP
      DOUBLE PRECISION EBMUP,XSECUP,XERRUP,XMAXUP
      COMMON/HEPRUP/IDBMUP(2),EBMUP(2),PDFGUP(2),PDFSUP(2),
     &		    IDWTUP, NPRUP,XSECUP(MAXPUP),XERRUP(MAXPUP),
     &		     XMAXUP(MAXPUP),LPRUP(MAXPUP)
      SAVE /HEPRUP/

*...PYTHIA USER PROCESS EVENT COMMON BLOCK
      INTEGER MAXNUP   ! Maximum number of particle entries
      PARAMETER (MAXNUP=500)
      INTEGER NUP,IDPRUP,IDUP,ISTUP,MOTHUP,ICOLUP
      DOUBLE PRECISION XWGTUP,SCALUP,AQEDUP,AQCDUP,PUP,VTIMUP,SPINUP
      COMMON/HEPEUP/NUP,IDPRUP,XWGTUP,SCALUP,AQEDUP,AQCDUP,
     &              IDUP(MAXNUP),ISTUP(MAXNUP),MOTHUP(2,MAXNUP),
     &              ICOLUP(2,MAXNUP),PUP(5,MAXNUP),VTIMUP(MAXNUP),
     &              SPINUP(MAXNUP)	       
      SAVE /HEPEUP/

*...CompHEP-PYTHIA interface
      COMMON/ISMEAR/ISMEAR
      COMMON/INPARM/IS,IST,NEVPY
      SAVE

****************** read CompHEP output header and input parameters
*...read input parameters from the file (INPARM.DAT)
      CALL RINPAR
*...switch to smear the mass of unstable particles in CompHEP out-state
      ISMEAR=1     ! 0 - no Breit-Wigner smearing, 1- yes
*...set some phys. parameters (masses etc) in PYTHIA according to CompHEP
*...default values
      CALL PHPARS
*...read header for event flow
      CALL READER(EVFILE)
*...check validity of header information
      CALL VALIDITY
*************   USER can change these switches or add others ********
*...Independent(MSTJ(1)=2)/LUND(=1)/NO(=0) Fragmentation Model switch
      MSTJ(1) = 1
*...switch on/off fragmentation and decays
      MSTP(111) = 1
*...switch on/off initial QCD and QED state radiation
      MSTP(61) = 1
*...switch on/off final state showers
      MSTP(71) = 1
*...switch off multiple interactions
      MSTP(81) = 1
*...title page off
      MSTU(12) = 0
*...no initialization and diff.cross-section maximization print-out
      MSTP(122) = 0

********************************************************************
*...initialize PYTHIA (using CompHEP output for kin.frame)
      CALL PYINIT('USER',' ',' ',0d0)
      CALL PHPARS    ! set again phys.parameters according to
                     ! CompHEP default values
*********************************************************
*...generate events by PYTHIA
      nnev = 0
      DO IEV=1,NEVPY
        CALL PYEVNT
        call pylist(1)    ! This is an example of user's routine:
        read(*,*)           !   to screen out event by event.

*...check end of file with partonic events
        IF (NUP.eq.0) THEN
            goto 300
        ELSE
            nnev = iev
        ENDIF
      ENDDO              ! DO 200 IEV=1,NEVPY

300   CLOSE(IS)
*...cross section table
      CALL PYSTAT(1)
      write(*,*) '  Generated events = ',nnev
      END
